.. Director documentation master file, created by sphinx-quickstart on Sat Sep 27 13:23:22 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Director's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   about
   examples
   development
   code
   tests

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

